# kframe

<!-- [![PyPI - Version](https://img.shields.io/pypi/v/kframe.svg)](https://pypi.org/project/kframe)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/kframe.svg)](https://pypi.org/project/kframe) -->
[![CI](https://github.com/kaeus-sgarcia/kframe/actions/workflows/main_ci.yml/badge.svg)](https://github.com/kaeus-sgarcia/kframe/actions/workflows/main_ci.yml)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install kframe
```

## License

Kaeus Framework &copy; 2024 by Kaeus Inc is licensed under [MS-PL](https://opensource.org/license/ms-pl-html) 
